c*************************************************************************
c GETACC_YARKOD.F
c*************************************************************************
c This subroutine calculates and ADDS the THERMAL acceleration for the
c test particles in the HELIOCENTRIC frame. Only Yarkovsky DIURNAL effect
c is included.
c
c Input:
c   nbod		number of massive bodies
c   ntp			number of test particles
c   mass(nbod)		masses array
c   xh,yh,zh		massive bodies' heliocentric coordinates
c   xht,yht,zht		test particles' heliocentric coordinates
c   istat		status of the test paricles
c   irht		inverse distances of tp's from the Sun
c			(were already calculated earlier in getacch.f)
c Output:
c   axht,ayht,azht	new tp's accelerations in helio coord
c
c Created by:  Miroslav Broz, miroslav.broz@usa.net
c Date:  Mar 16th 1999

      subroutine getacc_yarko(nbod,ntp,mass,xh,yh,zh,
     &     xht,yht,zht,istat,irht,axht,ayht,azht)

      include 'swift.inc'
      include 'filter.inc'

c...  Inputs: 
      integer nbod,ntp,istat(NTPMAX)
      real*8 mass(NPLMAX),xh(NPLMAX),yh(NPLMAX),zh(NPLMAX)
      real*8 xht(NTPMAX),yht(NTPMAX),zht(NTPMAX)

c  input thermal parameters in common block /yarko/
      integer MAXk_seasonal             ! max # of iterations in calculation
      parameter(MAXk_seasonal=7)        ! of seasonal yarkovsky effect
      integer*2 k_seasonal
      real*8 s(3,NTPMAX),lambda0(NTPMAX),Tstar40(NTPMAX),rho0(NTPMAX),
     :  lambdas0(NTPMAX),Rdash0(NTPMAX),thetas(NTPMAX),rhos0(NTPMAX),
     :  koefsin(MAXk_seasonal,NTPMAX),koefcos(MAXk_seasonal,NTPMAX)
      complex*8 psi(NTPMAX)
      common/yarko/s,psi,lambda0,Tstar40,rho0,lambdas0,Rdash0,
     :  thetas,rhos0,koefsin,koefcos,k_seasonal

c  input orbital elements computed in io_write_filter.f subroutine
c  in common block /elements/, we need also index of last computed value
c  and the epoch of mean anomaly t0
      real*8 elmts(FMAXN,6,-FMAXNPL:FMAXNTP,FMAXC)
      real*8 t0
      integer index
      common/elements/elmts,t0,index

c  following common block /times/ serves another parameter for seasonal
c  yarkovsky effect computation
      real*8 t,dt
      common/times/ t,dt

c...  Outputs:
      real*8 axht(NTPMAX),ayht(NTPMAX),azht(NTPMAX)
                
c...  Internals:
      integer i,k,i1st
      real*8 irht(NTPMAX)
      real*8 sin_theta_0,cos_theta_0,Tstar4,lambda,rho,n0(3),f1(3),
     &  ex(3),ey(3),x1,Tstar3,ath,n,l
      complex*8 psi2

c  the first calls of getacch.f subroutine are with 2 step in coordinates
c  and only one step in time, thus we have to correct expression for time
      data i1st/0/
      save i1st

c----
c...  Executable code 

      do i=1,ntp
c
c  yarkovsky diurnal force
c
        n0(1)=-xht(i)*irht(i)
        n0(2)=-yht(i)*irht(i)
        n0(3)=-zht(i)*irht(i)
        cos_theta_0=n0(1)*s(1,i)+n0(2)*s(2,i)+n0(3)*s(3,i)
        sin_theta_0=sqrt(1-cos_theta_0**2)
        Tstar4=Tstar40(i)*irht(i)**2
        Tstar3=Tstar4**(3./4.)
        lambda=lambda0(i)/Tstar3
        psi2=1/(1+(lambda/(1+lambda))*psi(i))
        rho=rho0(i)*Tstar4/(1.+lambda)

        f1(1)=rho*sin_theta_0*dble(psi2)
        f1(2)=-rho*sin_theta_0*imag(psi2)
        f1(3)=rho*cos_theta_0
c
c  transformation to ecliptic coordinate frame
c
        x1=1/sin_theta_0
        do k=1,3
          ex(k)=(n0(k)-cos_theta_0*s(k,i))*x1
        enddo
        ey(1)=(s(2,i)*n0(3)-s(3,i)*n0(2))*x1
        ey(2)=(s(3,i)*n0(1)-s(1,i)*n0(3))*x1
        ey(3)=(s(1,i)*n0(2)-s(2,i)*n0(1))*x1

        axht(i) = axht(i) + (ex(1)*f1(1)+ey(1)*f1(2)+s(1,i)*f1(3))
        ayht(i) = ayht(i) + (ex(2)*f1(1)+ey(2)*f1(2)+s(2,i)*f1(3))
        azht(i) = azht(i) + (ex(3)*f1(1)+ey(3)*f1(2)+s(3,i)*f1(3))

      enddo

      return
      end      ! getacc_yarko

c---------------------------------------------------------------------

